# -*- coding: utf-8 -*-
"""
Created on Sun Dec  4 17:12:37 2022

init.py

python-can-bluetooth
"""

from .version import __version__
from ._bluetooth_can import BluetoothSPPBus, BusCRCError
